#!/usr/bin/env python
# Copyright (c) 2022 Clément Martin <twisla@twis.la. All rights reserved.
# Unauthorized copying of this file, via any medium is strictly prohibited

from diagrams.custom import Custom

def AndroidPhone(label='Android Phone'):
    return Custom(label, './icons/android_phone.png')

def EliteBook(label='EliteBook'):
    return Custom(label, './icons/elitebook.png')

def IPhone(label='IPhone'):
    return Custom(label, './icons/iphone.png')

def Laptop(label='Laptop'):
    return Custom(label, './icons/laptop.png')

def NUC(label='Intel NUC'):
    return Custom(label, './icons/intel_nuc.png')

def Printer(label='Printer'):
    return Custom(label, './icons/printer.png')

def Rpi4(label='RaspBerryPi4'):
    return Custom(label, './icons/raspberry_pi.png')

def SynologyDS(label='Synology DiskStation'):
    return Custom(label, './icons/synology_ds.png')

def ThinkPad(label='Thinkpad'):
    return Custom(label, './icons/thinkpad.png')

def WashingMachine(label='Washing Machine'):
    return Custom(label, './icons/washing_machine.png')
